from setuptools import setup

setup(name='handle_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['handle_distributions'],
      author='Chamod perera',
      author_email= 'chamodperera87@gmail.com',
      zip_safe=False)
